:construction: Section under Construction :construction:

# Doctypes

Doctypes represent different types of data. Their primary use is for permissions: an app or konnector will request permissions for one or several doctypes and will not be able to access other doctypes. See [Doctypes documentation](https://docs.cozy.io/en/cozy-doctypes/docs/) for more information.

The following is a full description of the doctypes we use and their fields. Cozy doctypes won't be fully described. Instead, for every used one, we'll include a link to its official documentation.



## Used Cozy doctypes

- [`io.cozy.accounts`](https://docs.cozy.io/en/cozy-doctypes/docs/io.cozy.accounts): Konnector accounts
- [`io.cozy.contacts`](https://docs.cozy.io/en/cozy-doctypes/docs/io.cozy.contacts): Contacts
- [`io.cozy.contacts.groups`](https://docs.cozy.io/en/cozy-doctypes/docs/io.cozy.contacts.groups): Contacts groups
- [`io.cozy.files`](https://docs.cozy.io/en/cozy-doctypes/docs/io.cozy.files): Files
- [`io.cozy.permissions`](https://docs.cozy.io/en/cozy-doctypes/docs/io.cozy.permissions): Permissions of the instance
- [`io.cozy.todos.item`](https://docs.cozy.io/en/cozy-doctypes/docs/io.cozy.todos.item): Todos item
- [`io.cozy.triggers`](https://docs.cozy.io/en/cozy-doctypes/docs/io.cozy.triggers): Job triggers

## Used Cozy remote doctypes
This kind of doctype are set from the team. We have push two remote doctypes (each duplicate for rec and prod environment)

> Prod
- [`org.mps.store`]: Required for store information on back-endTS
- [`org.mps.share`]: Required for searching on back-endTS

> Recette 

- [`org.mps.store.rec`]: Required for store information on rec back-endTS
- [`org.mps.share.rec`]: Required for searching on rec back-endTS

If you need to target rec remote doctype, you need to change the request : client.getStackClient().fetchJSON('POST','...')
and change them into the manifest also. 

## Custom doctypes

- `com.grandlyon.mps.notes` 

  Represents ...

  `com.grandlyon.mps.notes`  attributes are: 

  - `title`: {string} The title of the note.
  - `content`: {string} The content of the note.

  #### Example

  ```json
  {
  	title: '...',
      content: '...',
  }
  ```

  

- `com.grandlyon.mps.profile`

  Represents the tutorial and notifications state. 

  `com.grandlyon.mps.profile` attributes are: 

  - `tutorial`: {object} contains `home`, `contacts`, `documents`, `actions`, and `notes` which are all of type `boolean`. Each one represents the state of its tutorial. For example, `home: true` means the home tutorial hasn't been seen yet and will be visible to the user the next time he visits the Home component.
  - `notification`: {} ...

  #### Example

  ```json
  {
      tutorial: {
          home: true,
          contacts: false,
          documents: true,
          actions: false,
          notes: true
         },
         notification: ...
      }
  }
  ```

- `com.grandlyon.mps.appointments`

  ...
  
- `com.grandlyon.mps.docrules`

  Represents ...

  `com.grandlyon.mps.docrules` attributes are:

  - `description`: {string} Description of the docrule.
  - `doctype`: {string} ...
  - `rule`: {object} Contains `limit` of type `number`and `selector` which is an `object` with the following attributes: 
    - `'cozyMetadata.classification'`: {string} Classification ...
    - `'cozyMetadata.createdAt'`: {object} Creation date.

  #### Example 

  ```json
  {
    description: '...',
    doctype: 'io.cozy.files',
    rule: {
      limit: 10,
      selector: {
        'cozyMetadata.classification': '...',
        'cozyMetadata.createdAt': 'December 23, 2020 03:24:00',
      }
    }
  }
  ```

